@@ -231,9 +231,6 @@ class Acquisition(object):
         magellan_explore=False,
         process=False,
         saving_queue_size=20,
-        omit_index=False,
-            ifd_off=False,
-            metadata_off=False,
         debug=False,
     ):
         """
@@ -300,8 +297,6 @@ class Acquisition(object):
             The number of images to queue (in memory) while waiting to write to disk. Higher values should
             in theory allow sequence acquisitions to go faster, but requires the RAM to hold images while
             they are waiting to save
-        debug : omit_index
-            Used for speed testing (if you set to True your data won't open)
         debug : bool
             whether to print debug messages
         """
@@ -352,9 +347,6 @@ class Acquisition(object):
                 y_overlap,
                 max_multi_res_index if max_multi_res_index is not None else -1,
                 saving_queue_size,
-                omit_index,
-                ifd_off,
-                metadata_off,
                 debug,
             )
         storage = self._remote_acq.get_data_sink()
